# Generated by default/object.tt
package Paws::AutoScaling::LaunchTemplate;
  use Moose;
  has LaunchTemplateSpecification => (is => 'ro', isa => 'Paws::AutoScaling::LaunchTemplateSpecification');
  has Overrides => (is => 'ro', isa => 'ArrayRef[Paws::AutoScaling::LaunchTemplateOverrides]');

1;

### main pod documentation begin ###

=head1 NAME

Paws::AutoScaling::LaunchTemplate

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::AutoScaling::LaunchTemplate object:

  $service_obj->Method(Att1 => { LaunchTemplateSpecification => $value, ..., Overrides => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::AutoScaling::LaunchTemplate object:

  $result = $service_obj->Method(...);
  $result->Att1->LaunchTemplateSpecification

=head1 DESCRIPTION

Describes a launch template and overrides.

You specify these properties as part of a mixed instances policy.

When you update the launch template or overrides, existing Amazon EC2
instances continue to run. When scale out occurs, Amazon EC2 Auto
Scaling launches instances to match the new settings. When scale in
occurs, Amazon EC2 Auto Scaling terminates instances according to the
group's termination policies.

=head1 ATTRIBUTES


=head2 LaunchTemplateSpecification => L<Paws::AutoScaling::LaunchTemplateSpecification>

The launch template to use.


=head2 Overrides => ArrayRef[L<Paws::AutoScaling::LaunchTemplateOverrides>]

Any properties that you specify override the same properties in the
launch template. If not provided, Amazon EC2 Auto Scaling uses the
instance type specified in the launch template when it launches an
instance.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::AutoScaling>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

