# Generated by default/object.tt
package Paws::Personalize::Filter;
  use Moose;
  has CreationDateTime => (is => 'ro', isa => 'Str', request_name => 'creationDateTime', traits => ['NameInRequest']);
  has DatasetGroupArn => (is => 'ro', isa => 'Str', request_name => 'datasetGroupArn', traits => ['NameInRequest']);
  has FailureReason => (is => 'ro', isa => 'Str', request_name => 'failureReason', traits => ['NameInRequest']);
  has FilterArn => (is => 'ro', isa => 'Str', request_name => 'filterArn', traits => ['NameInRequest']);
  has FilterExpression => (is => 'ro', isa => 'Str', request_name => 'filterExpression', traits => ['NameInRequest']);
  has LastUpdatedDateTime => (is => 'ro', isa => 'Str', request_name => 'lastUpdatedDateTime', traits => ['NameInRequest']);
  has Name => (is => 'ro', isa => 'Str', request_name => 'name', traits => ['NameInRequest']);
  has Status => (is => 'ro', isa => 'Str', request_name => 'status', traits => ['NameInRequest']);

1;

### main pod documentation begin ###

=head1 NAME

Paws::Personalize::Filter

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Personalize::Filter object:

  $service_obj->Method(Att1 => { CreationDateTime => $value, ..., Status => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Personalize::Filter object:

  $result = $service_obj->Method(...);
  $result->Att1->CreationDateTime

=head1 DESCRIPTION

Contains information on a recommendation filter, including its ARN,
status, and filter expression.

=head1 ATTRIBUTES


=head2 CreationDateTime => Str

The time at which the filter was created.


=head2 DatasetGroupArn => Str

The ARN of the dataset group to which the filter belongs.


=head2 FailureReason => Str

If the filter failed, the reason for its failure.


=head2 FilterArn => Str

The ARN of the filter.


=head2 FilterExpression => Str

Specifies the type of item interactions to filter out of recommendation
results. The filter expression must follow specific format rules. For
information about filter expression structure and syntax, see
filter-expressions.


=head2 LastUpdatedDateTime => Str

The time at which the filter was last updated.


=head2 Name => Str

The name of the filter.


=head2 Status => Str

The status of the filter.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Personalize>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

