
package Paws::LookoutMetrics::DescribeAlert;
  use Moose;
  has AlertArn => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeAlert');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/DescribeAlert');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'POST');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::LookoutMetrics::DescribeAlertResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::LookoutMetrics::DescribeAlert - Arguments for method DescribeAlert on L<Paws::LookoutMetrics>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeAlert on the
L<Amazon Lookout for Metrics|Paws::LookoutMetrics> service. Use the attributes of this class
as arguments to method DescribeAlert.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeAlert.

=head1 SYNOPSIS

    my $lookoutmetrics = Paws->service('LookoutMetrics');
    my $DescribeAlertResponse = $lookoutmetrics->DescribeAlert(
      AlertArn => 'MyArn',

    );

    # Results:
    my $Alert = $DescribeAlertResponse->Alert;

    # Returns a L<Paws::LookoutMetrics::DescribeAlertResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/lookoutmetrics/DescribeAlert>

=head1 ATTRIBUTES


=head2 B<REQUIRED> AlertArn => Str

The ARN of the alert to describe.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeAlert in L<Paws::LookoutMetrics>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

