# Generated by default/object.tt
package Paws::WellArchitected::LensReview;
  use Moose;
  has LensAlias => (is => 'ro', isa => 'Str');
  has LensName => (is => 'ro', isa => 'Str');
  has LensStatus => (is => 'ro', isa => 'Str');
  has LensVersion => (is => 'ro', isa => 'Str');
  has NextToken => (is => 'ro', isa => 'Str');
  has Notes => (is => 'ro', isa => 'Str');
  has PillarReviewSummaries => (is => 'ro', isa => 'ArrayRef[Paws::WellArchitected::PillarReviewSummary]');
  has RiskCounts => (is => 'ro', isa => 'Paws::WellArchitected::RiskCounts');
  has UpdatedAt => (is => 'ro', isa => 'Str');

1;

### main pod documentation begin ###

=head1 NAME

Paws::WellArchitected::LensReview

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::WellArchitected::LensReview object:

  $service_obj->Method(Att1 => { LensAlias => $value, ..., UpdatedAt => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::WellArchitected::LensReview object:

  $result = $service_obj->Method(...);
  $result->Att1->LensAlias

=head1 DESCRIPTION

A lens review of a question.

=head1 ATTRIBUTES


=head2 LensAlias => Str




=head2 LensName => Str




=head2 LensStatus => Str

The status of the lens.


=head2 LensVersion => Str

The version of the lens.


=head2 NextToken => Str




=head2 Notes => Str




=head2 PillarReviewSummaries => ArrayRef[L<Paws::WellArchitected::PillarReviewSummary>]




=head2 RiskCounts => L<Paws::WellArchitected::RiskCounts>




=head2 UpdatedAt => Str





=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::WellArchitected>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

