
package Paws::FSX::DisassociateFileSystemAliases;
  use Moose;
  has Aliases => (is => 'ro', isa => 'ArrayRef[Str|Undef]', required => 1);
  has ClientRequestToken => (is => 'ro', isa => 'Str');
  has FileSystemId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisassociateFileSystemAliases');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::FSX::DisassociateFileSystemAliasesResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::FSX::DisassociateFileSystemAliases - Arguments for method DisassociateFileSystemAliases on L<Paws::FSX>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisassociateFileSystemAliases on the
L<Amazon FSx|Paws::FSX> service. Use the attributes of this class
as arguments to method DisassociateFileSystemAliases.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisassociateFileSystemAliases.

=head1 SYNOPSIS

    my $fsx = Paws->service('FSX');
    my $DisassociateFileSystemAliasesResponse =
      $fsx->DisassociateFileSystemAliases(
      Aliases => [
        'MyAlternateDNSName', ...    # min: 4, max: 253
      ],
      FileSystemId       => 'MyFileSystemId',
      ClientRequestToken => 'MyClientRequestToken',    # OPTIONAL
      );

    # Results:
    my $Aliases = $DisassociateFileSystemAliasesResponse->Aliases;

    # Returns a L<Paws::FSX::DisassociateFileSystemAliasesResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/fsx/DisassociateFileSystemAliases>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Aliases => ArrayRef[Str|Undef]

An array of one or more DNS alias names to disassociate, or remove,
from the file system.



=head2 ClientRequestToken => Str





=head2 B<REQUIRED> FileSystemId => Str

Specifies the file system from which to disassociate the DNS aliases.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisassociateFileSystemAliases in L<Paws::FSX>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

