
package Paws::RDS::RegisterDBProxyTargets;
  use Moose;
  has DBClusterIdentifiers => (is => 'ro', isa => 'ArrayRef[Str|Undef]');
  has DBInstanceIdentifiers => (is => 'ro', isa => 'ArrayRef[Str|Undef]');
  has DBProxyName => (is => 'ro', isa => 'Str', required => 1);
  has TargetGroupName => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'RegisterDBProxyTargets');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::RDS::RegisterDBProxyTargetsResponse');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'RegisterDBProxyTargetsResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::RDS::RegisterDBProxyTargets - Arguments for method RegisterDBProxyTargets on L<Paws::RDS>

=head1 DESCRIPTION

This class represents the parameters used for calling the method RegisterDBProxyTargets on the
L<Amazon Relational Database Service|Paws::RDS> service. Use the attributes of this class
as arguments to method RegisterDBProxyTargets.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to RegisterDBProxyTargets.

=head1 SYNOPSIS

    my $rds = Paws->service('RDS');
    my $RegisterDBProxyTargetsResponse = $rds->RegisterDBProxyTargets(
      DBProxyName           => 'MyString',
      DBClusterIdentifiers  => [ 'MyString', ... ],    # OPTIONAL
      DBInstanceIdentifiers => [ 'MyString', ... ],    # OPTIONAL
      TargetGroupName       => 'MyString',             # OPTIONAL
    );

    # Results:
    my $DBProxyTargets = $RegisterDBProxyTargetsResponse->DBProxyTargets;

    # Returns a L<Paws::RDS::RegisterDBProxyTargetsResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/rds/RegisterDBProxyTargets>

=head1 ATTRIBUTES


=head2 DBClusterIdentifiers => ArrayRef[Str|Undef]

One or more DB cluster identifiers.



=head2 DBInstanceIdentifiers => ArrayRef[Str|Undef]

One or more DB instance identifiers.



=head2 B<REQUIRED> DBProxyName => Str

The identifier of the C<DBProxy> that is associated with the
C<DBProxyTargetGroup>.



=head2 TargetGroupName => Str

The identifier of the C<DBProxyTargetGroup>.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method RegisterDBProxyTargets in L<Paws::RDS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

