# Generated by default/object.tt
package Paws::XRay::TimeSeriesServiceStatistics;
  use Moose;
  has EdgeSummaryStatistics => (is => 'ro', isa => 'Paws::XRay::EdgeStatistics');
  has ResponseTimeHistogram => (is => 'ro', isa => 'ArrayRef[Paws::XRay::HistogramEntry]');
  has ServiceForecastStatistics => (is => 'ro', isa => 'Paws::XRay::ForecastStatistics');
  has ServiceSummaryStatistics => (is => 'ro', isa => 'Paws::XRay::ServiceStatistics');
  has Timestamp => (is => 'ro', isa => 'Str');

1;

### main pod documentation begin ###

=head1 NAME

Paws::XRay::TimeSeriesServiceStatistics

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::XRay::TimeSeriesServiceStatistics object:

  $service_obj->Method(Att1 => { EdgeSummaryStatistics => $value, ..., Timestamp => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::XRay::TimeSeriesServiceStatistics object:

  $result = $service_obj->Method(...);
  $result->Att1->EdgeSummaryStatistics

=head1 DESCRIPTION

A list of TimeSeriesStatistic structures.

=head1 ATTRIBUTES


=head2 EdgeSummaryStatistics => L<Paws::XRay::EdgeStatistics>




=head2 ResponseTimeHistogram => ArrayRef[L<Paws::XRay::HistogramEntry>]

The response time histogram for the selected entities.


=head2 ServiceForecastStatistics => L<Paws::XRay::ForecastStatistics>

The forecasted high and low fault count values.


=head2 ServiceSummaryStatistics => L<Paws::XRay::ServiceStatistics>




=head2 Timestamp => Str

Timestamp of the window for which statistics are aggregated.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::XRay>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

