# Generated by default/object.tt
package Paws::DeviceFarm::Tag;
  use Moose;
  has Key => (is => 'ro', isa => 'Str', required => 1);
  has Value => (is => 'ro', isa => 'Str', required => 1);

1;

### main pod documentation begin ###

=head1 NAME

Paws::DeviceFarm::Tag

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::DeviceFarm::Tag object:

  $service_obj->Method(Att1 => { Key => $value, ..., Value => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::DeviceFarm::Tag object:

  $result = $service_obj->Method(...);
  $result->Att1->Key

=head1 DESCRIPTION

The metadata that you apply to a resource to help you categorize and
organize it. Each tag consists of a key and an optional value, both of
which you define. Tag keys can have a maximum character length of 128
characters. Tag values can have a maximum length of 256 characters.

=head1 ATTRIBUTES


=head2 B<REQUIRED> Key => Str

One part of a key-value pair that makes up a tag. A C<key> is a general
label that acts like a category for more specific tag values.


=head2 B<REQUIRED> Value => Str

The optional part of a key-value pair that makes up a tag. A C<value>
acts as a descriptor in a tag category (key).



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::DeviceFarm>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

