# Generated by default/object.tt
package Paws::SageMaker::MonitoringBaselineConfig;
  use Moose;
  has BaseliningJobName => (is => 'ro', isa => 'Str');
  has ConstraintsResource => (is => 'ro', isa => 'Paws::SageMaker::MonitoringConstraintsResource');
  has StatisticsResource => (is => 'ro', isa => 'Paws::SageMaker::MonitoringStatisticsResource');

1;

### main pod documentation begin ###

=head1 NAME

Paws::SageMaker::MonitoringBaselineConfig

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::SageMaker::MonitoringBaselineConfig object:

  $service_obj->Method(Att1 => { BaseliningJobName => $value, ..., StatisticsResource => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::SageMaker::MonitoringBaselineConfig object:

  $result = $service_obj->Method(...);
  $result->Att1->BaseliningJobName

=head1 DESCRIPTION

Configuration for monitoring constraints and monitoring statistics.
These baseline resources are compared against the results of the
current job from the series of jobs scheduled to collect data
periodically.

=head1 ATTRIBUTES


=head2 BaseliningJobName => Str

The name of the job that performs baselining for the monitoring job.


=head2 ConstraintsResource => L<Paws::SageMaker::MonitoringConstraintsResource>

The baseline constraint file in Amazon S3 that the current monitoring
job should validated against.


=head2 StatisticsResource => L<Paws::SageMaker::MonitoringStatisticsResource>

The baseline statistics file in Amazon S3 that the current monitoring
job should be validated against.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::SageMaker>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

