# Generated by default/object.tt
package Paws::LakeFormation::LFTagPolicyResource;
  use Moose;
  has CatalogId => (is => 'ro', isa => 'Str');
  has Expression => (is => 'ro', isa => 'ArrayRef[Paws::LakeFormation::LFTag]', required => 1);
  has ResourceType => (is => 'ro', isa => 'Str', required => 1);

1;

### main pod documentation begin ###

=head1 NAME

Paws::LakeFormation::LFTagPolicyResource

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::LakeFormation::LFTagPolicyResource object:

  $service_obj->Method(Att1 => { CatalogId => $value, ..., ResourceType => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::LakeFormation::LFTagPolicyResource object:

  $result = $service_obj->Method(...);
  $result->Att1->CatalogId

=head1 DESCRIPTION

A structure containing a list of tag conditions that apply to a
resource's tag policy.

=head1 ATTRIBUTES


=head2 CatalogId => Str

The identifier for the Data Catalog. By default, the account ID. The
Data Catalog is the persistent metadata store. It contains database
definitions, table definitions, and other control information to manage
your AWS Lake Formation environment.


=head2 B<REQUIRED> Expression => ArrayRef[L<Paws::LakeFormation::LFTag>]

A list of tag conditions that apply to the resource's tag policy.


=head2 B<REQUIRED> ResourceType => Str

The resource type for which the tag policy applies.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::LakeFormation>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

