
package Paws::Amplify::DeleteWebhookResult;
  use Moose;
  has Webhook => (is => 'ro', isa => 'Paws::Amplify::Webhook', traits => ['NameInRequest'], request_name => 'webhook', required => 1);

  has _request_id => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Amplify::DeleteWebhookResult

=head1 ATTRIBUTES


=head2 B<REQUIRED> Webhook => L<Paws::Amplify::Webhook>

Describes a webhook that connects repository events to an Amplify app.


=head2 _request_id => Str


=cut

