# Generated by default/object.tt
package Paws::AutoScaling::MetricCollectionType;
  use Moose;
  has Metric => (is => 'ro', isa => 'Str');

1;

### main pod documentation begin ###

=head1 NAME

Paws::AutoScaling::MetricCollectionType

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::AutoScaling::MetricCollectionType object:

  $service_obj->Method(Att1 => { Metric => $value, ..., Metric => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::AutoScaling::MetricCollectionType object:

  $result = $service_obj->Method(...);
  $result->Att1->Metric

=head1 DESCRIPTION

Describes a metric.

=head1 ATTRIBUTES


=head2 Metric => Str

One of the following metrics:

=over

=item *

C<GroupMinSize>

=item *

C<GroupMaxSize>

=item *

C<GroupDesiredCapacity>

=item *

C<GroupInServiceInstances>

=item *

C<GroupPendingInstances>

=item *

C<GroupStandbyInstances>

=item *

C<GroupTerminatingInstances>

=item *

C<GroupTotalInstances>

=item *

C<GroupInServiceCapacity>

=item *

C<GroupPendingCapacity>

=item *

C<GroupStandbyCapacity>

=item *

C<GroupTerminatingCapacity>

=item *

C<GroupTotalCapacity>

=item *

C<WarmPoolDesiredCapacity>

=item *

C<WarmPoolWarmedCapacity>

=item *

C<WarmPoolPendingCapacity>

=item *

C<WarmPoolTerminatingCapacity>

=item *

C<WarmPoolTotalCapacity>

=item *

C<GroupAndWarmPoolDesiredCapacity>

=item *

C<GroupAndWarmPoolTotalCapacity>

=back




=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::AutoScaling>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

