# Generated by default/object.tt
package Paws::S3::QueueConfigurationDeprecated;
  use Moose;
  has Event => (is => 'ro', isa => 'Str');
  has Events => (is => 'ro', isa => 'ArrayRef[Str|Undef]', request_name => 'Event', traits => ['NameInRequest']);
  has Id => (is => 'ro', isa => 'Str');
  has Queue => (is => 'ro', isa => 'Str');

1;

### main pod documentation begin ###

=head1 NAME

Paws::S3::QueueConfigurationDeprecated

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::S3::QueueConfigurationDeprecated object:

  $service_obj->Method(Att1 => { Event => $value, ..., Queue => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::S3::QueueConfigurationDeprecated object:

  $result = $service_obj->Method(...);
  $result->Att1->Event

=head1 DESCRIPTION

This data type is deprecated. Use QueueConfiguration
(https://docs.aws.amazon.com/AmazonS3/latest/API/API_QueueConfiguration.html)
for the same purposes. This data type specifies the configuration for
publishing messages to an Amazon Simple Queue Service (Amazon SQS)
queue when Amazon S3 detects specified events.

=head1 ATTRIBUTES


=head2 Event => Str




=head2 Events => ArrayRef[Str|Undef]

A collection of bucket events for which to send notifications.


=head2 Id => Str




=head2 Queue => Str

The Amazon Resource Name (ARN) of the Amazon SQS queue to which Amazon
S3 publishes a message when it detects events of the specified type.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::S3>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

