# Generated by default/object.tt
package Paws::Appflow::ConnectorProfileProperties;
  use Moose;
  has Amplitude => (is => 'ro', isa => 'Paws::Appflow::AmplitudeConnectorProfileProperties');
  has Datadog => (is => 'ro', isa => 'Paws::Appflow::DatadogConnectorProfileProperties');
  has Dynatrace => (is => 'ro', isa => 'Paws::Appflow::DynatraceConnectorProfileProperties');
  has GoogleAnalytics => (is => 'ro', isa => 'Paws::Appflow::GoogleAnalyticsConnectorProfileProperties');
  has Honeycode => (is => 'ro', isa => 'Paws::Appflow::HoneycodeConnectorProfileProperties');
  has InforNexus => (is => 'ro', isa => 'Paws::Appflow::InforNexusConnectorProfileProperties');
  has Marketo => (is => 'ro', isa => 'Paws::Appflow::MarketoConnectorProfileProperties');
  has Redshift => (is => 'ro', isa => 'Paws::Appflow::RedshiftConnectorProfileProperties');
  has Salesforce => (is => 'ro', isa => 'Paws::Appflow::SalesforceConnectorProfileProperties');
  has ServiceNow => (is => 'ro', isa => 'Paws::Appflow::ServiceNowConnectorProfileProperties');
  has Singular => (is => 'ro', isa => 'Paws::Appflow::SingularConnectorProfileProperties');
  has Slack => (is => 'ro', isa => 'Paws::Appflow::SlackConnectorProfileProperties');
  has Snowflake => (is => 'ro', isa => 'Paws::Appflow::SnowflakeConnectorProfileProperties');
  has Trendmicro => (is => 'ro', isa => 'Paws::Appflow::TrendmicroConnectorProfileProperties');
  has Veeva => (is => 'ro', isa => 'Paws::Appflow::VeevaConnectorProfileProperties');
  has Zendesk => (is => 'ro', isa => 'Paws::Appflow::ZendeskConnectorProfileProperties');

1;

### main pod documentation begin ###

=head1 NAME

Paws::Appflow::ConnectorProfileProperties

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Appflow::ConnectorProfileProperties object:

  $service_obj->Method(Att1 => { Amplitude => $value, ..., Zendesk => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Appflow::ConnectorProfileProperties object:

  $result = $service_obj->Method(...);
  $result->Att1->Amplitude

=head1 DESCRIPTION

The connector-specific profile properties required by each connector.

=head1 ATTRIBUTES


=head2 Amplitude => L<Paws::Appflow::AmplitudeConnectorProfileProperties>

The connector-specific properties required by Amplitude.


=head2 Datadog => L<Paws::Appflow::DatadogConnectorProfileProperties>

The connector-specific properties required by Datadog.


=head2 Dynatrace => L<Paws::Appflow::DynatraceConnectorProfileProperties>

The connector-specific properties required by Dynatrace.


=head2 GoogleAnalytics => L<Paws::Appflow::GoogleAnalyticsConnectorProfileProperties>

The connector-specific properties required Google Analytics.


=head2 Honeycode => L<Paws::Appflow::HoneycodeConnectorProfileProperties>

The connector-specific properties required by Amazon Honeycode.


=head2 InforNexus => L<Paws::Appflow::InforNexusConnectorProfileProperties>

The connector-specific properties required by Infor Nexus.


=head2 Marketo => L<Paws::Appflow::MarketoConnectorProfileProperties>

The connector-specific properties required by Marketo.


=head2 Redshift => L<Paws::Appflow::RedshiftConnectorProfileProperties>

The connector-specific properties required by Amazon Redshift.


=head2 Salesforce => L<Paws::Appflow::SalesforceConnectorProfileProperties>

The connector-specific properties required by Salesforce.


=head2 ServiceNow => L<Paws::Appflow::ServiceNowConnectorProfileProperties>

The connector-specific properties required by serviceNow.


=head2 Singular => L<Paws::Appflow::SingularConnectorProfileProperties>

The connector-specific properties required by Singular.


=head2 Slack => L<Paws::Appflow::SlackConnectorProfileProperties>

The connector-specific properties required by Slack.


=head2 Snowflake => L<Paws::Appflow::SnowflakeConnectorProfileProperties>

The connector-specific properties required by Snowflake.


=head2 Trendmicro => L<Paws::Appflow::TrendmicroConnectorProfileProperties>

The connector-specific properties required by Trend Micro.


=head2 Veeva => L<Paws::Appflow::VeevaConnectorProfileProperties>

The connector-specific properties required by Veeva.


=head2 Zendesk => L<Paws::Appflow::ZendeskConnectorProfileProperties>

The connector-specific properties required by Zendesk.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Appflow>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

