
package Paws::EFS::DescribeLifecycleConfiguration;
  use Moose;
  has FileSystemId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'FileSystemId', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeLifecycleConfiguration');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/2015-02-01/file-systems/{FileSystemId}/lifecycle-configuration');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EFS::LifecycleConfigurationDescription');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EFS::DescribeLifecycleConfiguration - Arguments for method DescribeLifecycleConfiguration on L<Paws::EFS>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeLifecycleConfiguration on the
L<Amazon Elastic File System|Paws::EFS> service. Use the attributes of this class
as arguments to method DescribeLifecycleConfiguration.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeLifecycleConfiguration.

=head1 SYNOPSIS

    my $elasticfilesystem = Paws->service('EFS');
# To describe the lifecycle configuration for a file system
# This operation describes a file system's LifecycleConfiguration. EFS lifecycle
# management uses the LifecycleConfiguration object to identify which files to
# move to the EFS Infrequent Access (IA) storage class.
    my $LifecycleConfigurationDescription =
      $elasticfilesystem->DescribeLifecycleConfiguration(
      'FileSystemId' => 'fs-01234567' );

    # Results:
    my $LifecyclePolicies =
      $LifecycleConfigurationDescription->LifecyclePolicies;

    # Returns a L<Paws::EFS::LifecycleConfigurationDescription> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/elasticfilesystem/DescribeLifecycleConfiguration>

=head1 ATTRIBUTES


=head2 B<REQUIRED> FileSystemId => Str

The ID of the file system whose C<LifecycleConfiguration> object you
want to retrieve (String).




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeLifecycleConfiguration in L<Paws::EFS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

