# Generated by default/object.tt
package Paws::IAM::AttachedPermissionsBoundary;
  use Moose;
  has PermissionsBoundaryArn => (is => 'ro', isa => 'Str');
  has PermissionsBoundaryType => (is => 'ro', isa => 'Str');

1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::AttachedPermissionsBoundary

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::IAM::AttachedPermissionsBoundary object:

  $service_obj->Method(Att1 => { PermissionsBoundaryArn => $value, ..., PermissionsBoundaryType => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::IAM::AttachedPermissionsBoundary object:

  $result = $service_obj->Method(...);
  $result->Att1->PermissionsBoundaryArn

=head1 DESCRIPTION

Contains information about an attached permissions boundary.

An attached permissions boundary is a managed policy that has been
attached to a user or role to set the permissions boundary.

For more information about permissions boundaries, see Permissions
boundaries for IAM identities
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_boundaries.html)
in the I<IAM User Guide>.

=head1 ATTRIBUTES


=head2 PermissionsBoundaryArn => Str

The ARN of the policy used to set the permissions boundary for the user
or role.


=head2 PermissionsBoundaryType => Str

The permissions boundary usage type that indicates what type of IAM
resource is used as the permissions boundary for an entity. This data
type can only have a value of C<Policy>.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::IAM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

