# Generated by default/object.tt
package Paws::Glue::DateColumnStatisticsData;
  use Moose;
  has MaximumValue => (is => 'ro', isa => 'Str');
  has MinimumValue => (is => 'ro', isa => 'Str');
  has NumberOfDistinctValues => (is => 'ro', isa => 'Int', required => 1);
  has NumberOfNulls => (is => 'ro', isa => 'Int', required => 1);

1;

### main pod documentation begin ###

=head1 NAME

Paws::Glue::DateColumnStatisticsData

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Glue::DateColumnStatisticsData object:

  $service_obj->Method(Att1 => { MaximumValue => $value, ..., NumberOfNulls => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Glue::DateColumnStatisticsData object:

  $result = $service_obj->Method(...);
  $result->Att1->MaximumValue

=head1 DESCRIPTION

Defines column statistics supported for timestamp data columns.

=head1 ATTRIBUTES


=head2 MaximumValue => Str

The highest value in the column.


=head2 MinimumValue => Str

The lowest value in the column.


=head2 B<REQUIRED> NumberOfDistinctValues => Int

The number of distinct values in a column.


=head2 B<REQUIRED> NumberOfNulls => Int

The number of null values in the column.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Glue>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

