# Generated by default/object.tt
package Paws::LexModelsV2::BotAliasLocaleSettings;
  use Moose;
  has CodeHookSpecification => (is => 'ro', isa => 'Paws::LexModelsV2::CodeHookSpecification', request_name => 'codeHookSpecification', traits => ['NameInRequest']);
  has Enabled => (is => 'ro', isa => 'Bool', request_name => 'enabled', traits => ['NameInRequest'], required => 1);

1;

### main pod documentation begin ###

=head1 NAME

Paws::LexModelsV2::BotAliasLocaleSettings

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::LexModelsV2::BotAliasLocaleSettings object:

  $service_obj->Method(Att1 => { CodeHookSpecification => $value, ..., Enabled => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::LexModelsV2::BotAliasLocaleSettings object:

  $result = $service_obj->Method(...);
  $result->Att1->CodeHookSpecification

=head1 DESCRIPTION

Specifies settings that are unique to a locale. For example, you can
use different Lambda function depending on the bot's locale.

=head1 ATTRIBUTES


=head2 CodeHookSpecification => L<Paws::LexModelsV2::CodeHookSpecification>

Specifies the Lambda function that should be used in the locale.


=head2 B<REQUIRED> Enabled => Bool

Determines whether the locale is enabled for the bot. If the value is
C<false>, the locale isn't available for use.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::LexModelsV2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

