# Generated by default/object.tt
package Paws::SESv2::ImportDataSource;
  use Moose;
  has DataFormat => (is => 'ro', isa => 'Str', required => 1);
  has S3Url => (is => 'ro', isa => 'Str', required => 1);

1;

### main pod documentation begin ###

=head1 NAME

Paws::SESv2::ImportDataSource

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::SESv2::ImportDataSource object:

  $service_obj->Method(Att1 => { DataFormat => $value, ..., S3Url => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::SESv2::ImportDataSource object:

  $result = $service_obj->Method(...);
  $result->Att1->DataFormat

=head1 DESCRIPTION

An object that contains details about the data source of the import
job.

=head1 ATTRIBUTES


=head2 B<REQUIRED> DataFormat => Str

The data format of the import job's data source.


=head2 B<REQUIRED> S3Url => Str

An Amazon S3 URL in the format
s3://I<E<lt>bucket_nameE<gt>>/I<E<lt>objectE<gt>>.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::SESv2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

