
package Paws::Athena::ListTableMetadataOutput;
  use Moose;
  has NextToken => (is => 'ro', isa => 'Str');
  has TableMetadataList => (is => 'ro', isa => 'ArrayRef[Paws::Athena::TableMetadata]');

  has _request_id => (is => 'ro', isa => 'Str');

### main pod documentation begin ###

=head1 NAME

Paws::Athena::ListTableMetadataOutput

=head1 ATTRIBUTES


=head2 NextToken => Str

A token generated by the Athena service that specifies where to
continue pagination if a previous request was truncated. To obtain the
next set of pages, pass in the NextToken from the response object of
the previous page call.


=head2 TableMetadataList => ArrayRef[L<Paws::Athena::TableMetadata>]

A list of table metadata.


=head2 _request_id => Str


=cut

1;