
package Paws::Glue::GetMLTransform;
  use Moose;
  has TransformId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetMLTransform');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Glue::GetMLTransformResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Glue::GetMLTransform - Arguments for method GetMLTransform on L<Paws::Glue>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetMLTransform on the
L<AWS Glue|Paws::Glue> service. Use the attributes of this class
as arguments to method GetMLTransform.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetMLTransform.

=head1 SYNOPSIS

    my $glue = Paws->service('Glue');
    my $GetMLTransformResponse = $glue->GetMLTransform(
      TransformId => 'MyHashString',

    );

    # Results:
    my $CreatedOn           = $GetMLTransformResponse->CreatedOn;
    my $Description         = $GetMLTransformResponse->Description;
    my $EvaluationMetrics   = $GetMLTransformResponse->EvaluationMetrics;
    my $GlueVersion         = $GetMLTransformResponse->GlueVersion;
    my $InputRecordTables   = $GetMLTransformResponse->InputRecordTables;
    my $LabelCount          = $GetMLTransformResponse->LabelCount;
    my $LastModifiedOn      = $GetMLTransformResponse->LastModifiedOn;
    my $MaxCapacity         = $GetMLTransformResponse->MaxCapacity;
    my $MaxRetries          = $GetMLTransformResponse->MaxRetries;
    my $Name                = $GetMLTransformResponse->Name;
    my $NumberOfWorkers     = $GetMLTransformResponse->NumberOfWorkers;
    my $Parameters          = $GetMLTransformResponse->Parameters;
    my $Role                = $GetMLTransformResponse->Role;
    my $Schema              = $GetMLTransformResponse->Schema;
    my $Status              = $GetMLTransformResponse->Status;
    my $Timeout             = $GetMLTransformResponse->Timeout;
    my $TransformEncryption = $GetMLTransformResponse->TransformEncryption;
    my $TransformId         = $GetMLTransformResponse->TransformId;
    my $WorkerType          = $GetMLTransformResponse->WorkerType;

    # Returns a L<Paws::Glue::GetMLTransformResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/glue/GetMLTransform>

=head1 ATTRIBUTES


=head2 B<REQUIRED> TransformId => Str

The unique identifier of the transform, generated at the time that the
transform was created.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetMLTransform in L<Paws::Glue>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

