
package Paws::IAM::GetAccessKeyLastUsed;
  use Moose;
  has AccessKeyId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetAccessKeyLastUsed');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IAM::GetAccessKeyLastUsedResponse');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'GetAccessKeyLastUsedResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::GetAccessKeyLastUsed - Arguments for method GetAccessKeyLastUsed on L<Paws::IAM>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetAccessKeyLastUsed on the
L<AWS Identity and Access Management|Paws::IAM> service. Use the attributes of this class
as arguments to method GetAccessKeyLastUsed.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetAccessKeyLastUsed.

=head1 SYNOPSIS

    my $iam = Paws->service('IAM');
    my $GetAccessKeyLastUsedResponse = $iam->GetAccessKeyLastUsed(
      AccessKeyId => 'MyaccessKeyIdType',

    );

    # Results:
    my $AccessKeyLastUsed = $GetAccessKeyLastUsedResponse->AccessKeyLastUsed;
    my $UserName          = $GetAccessKeyLastUsedResponse->UserName;

    # Returns a L<Paws::IAM::GetAccessKeyLastUsedResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/iam/GetAccessKeyLastUsed>

=head1 ATTRIBUTES


=head2 B<REQUIRED> AccessKeyId => Str

The identifier of an access key.

This parameter allows (through its regex pattern
(http://wikipedia.org/wiki/regex)) a string of characters that can
consist of any upper or lowercased letter or digit.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetAccessKeyLastUsed in L<Paws::IAM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

