# Generated by default/object.tt
package Paws::Kendra::AdditionalResultAttribute;
  use Moose;
  has Key => (is => 'ro', isa => 'Str', required => 1);
  has Value => (is => 'ro', isa => 'Paws::Kendra::AdditionalResultAttributeValue', required => 1);
  has ValueType => (is => 'ro', isa => 'Str', required => 1);

1;

### main pod documentation begin ###

=head1 NAME

Paws::Kendra::AdditionalResultAttribute

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Kendra::AdditionalResultAttribute object:

  $service_obj->Method(Att1 => { Key => $value, ..., ValueType => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Kendra::AdditionalResultAttribute object:

  $result = $service_obj->Method(...);
  $result->Att1->Key

=head1 DESCRIPTION

An attribute returned from an index query.

=head1 ATTRIBUTES


=head2 B<REQUIRED> Key => Str

The key that identifies the attribute.


=head2 B<REQUIRED> Value => L<Paws::Kendra::AdditionalResultAttributeValue>

An object that contains the attribute value.


=head2 B<REQUIRED> ValueType => Str

The data type of the C<Value> property.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Kendra>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

