
package Paws::Datasync::UpdateAgent;
  use Moose;
  has AgentArn => (is => 'ro', isa => 'Str', required => 1);
  has Name => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'UpdateAgent');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Datasync::UpdateAgentResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Datasync::UpdateAgent - Arguments for method UpdateAgent on L<Paws::Datasync>

=head1 DESCRIPTION

This class represents the parameters used for calling the method UpdateAgent on the
L<AWS DataSync|Paws::Datasync> service. Use the attributes of this class
as arguments to method UpdateAgent.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to UpdateAgent.

=head1 SYNOPSIS

    my $datasync = Paws->service('Datasync');
    my $UpdateAgentResponse = $datasync->UpdateAgent(
      AgentArn => 'MyAgentArn',
      Name     => 'MyTagValue',    # OPTIONAL
    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/datasync/UpdateAgent>

=head1 ATTRIBUTES


=head2 B<REQUIRED> AgentArn => Str

The Amazon Resource Name (ARN) of the agent to update.



=head2 Name => Str

The name that you want to use to configure the agent.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method UpdateAgent in L<Paws::Datasync>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

