# Generated by default/object.tt
package Paws::LookoutMetrics::AlertSummary;
  use Moose;
  has AlertArn => (is => 'ro', isa => 'Str');
  has AlertName => (is => 'ro', isa => 'Str');
  has AlertSensitivityThreshold => (is => 'ro', isa => 'Int');
  has AlertStatus => (is => 'ro', isa => 'Str');
  has AlertType => (is => 'ro', isa => 'Str');
  has AnomalyDetectorArn => (is => 'ro', isa => 'Str');
  has CreationTime => (is => 'ro', isa => 'Str');
  has LastModificationTime => (is => 'ro', isa => 'Str');
  has Tags => (is => 'ro', isa => 'Paws::LookoutMetrics::TagMap');

1;

### main pod documentation begin ###

=head1 NAME

Paws::LookoutMetrics::AlertSummary

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::LookoutMetrics::AlertSummary object:

  $service_obj->Method(Att1 => { AlertArn => $value, ..., Tags => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::LookoutMetrics::AlertSummary object:

  $result = $service_obj->Method(...);
  $result->Att1->AlertArn

=head1 DESCRIPTION

Provides a summary of an alert's configuration.

=head1 ATTRIBUTES


=head2 AlertArn => Str

The ARN of the alert.


=head2 AlertName => Str

The name of the alert.


=head2 AlertSensitivityThreshold => Int

The minimum severity for an anomaly to trigger the alert.


=head2 AlertStatus => Str

The status of the alert.


=head2 AlertType => Str

The type of the alert.


=head2 AnomalyDetectorArn => Str

The ARN of the detector to which the alert is attached.


=head2 CreationTime => Str

The time at which the alert was created.


=head2 LastModificationTime => Str

The time at which the alert was last modified.


=head2 Tags => L<Paws::LookoutMetrics::TagMap>

The alert's tags
(https://docs.aws.amazon.com/lookoutmetrics/latest/dev/detectors-tags.html).



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::LookoutMetrics>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

