
package Paws::RDS::GlobalClustersMessage;
  use Moose;
  has GlobalClusters => (is => 'ro', isa => 'ArrayRef[Paws::RDS::GlobalCluster]', request_name => 'GlobalClusterMember', traits => ['NameInRequest',]);
  has Marker => (is => 'ro', isa => 'Str');

  has _request_id => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::RDS::GlobalClustersMessage

=head1 ATTRIBUTES


=head2 GlobalClusters => ArrayRef[L<Paws::RDS::GlobalCluster>]

The list of global clusters returned by this request.


=head2 Marker => Str

An optional pagination token provided by a previous
C<DescribeGlobalClusters> request. If this parameter is specified, the
response includes only records beyond the marker, up to the value
specified by C<MaxRecords>.


=head2 _request_id => Str


=cut

