# Generated by default/object.tt
package Paws::AmplifyBackend::EmailSettings;
  use Moose;
  has EmailMessage => (is => 'ro', isa => 'Str', request_name => 'emailMessage', traits => ['NameInRequest']);
  has EmailSubject => (is => 'ro', isa => 'Str', request_name => 'emailSubject', traits => ['NameInRequest']);

1;

### main pod documentation begin ###

=head1 NAME

Paws::AmplifyBackend::EmailSettings

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::AmplifyBackend::EmailSettings object:

  $service_obj->Method(Att1 => { EmailMessage => $value, ..., EmailSubject => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::AmplifyBackend::EmailSettings object:

  $result = $service_obj->Method(...);
  $result->Att1->EmailMessage

=head1 DESCRIPTION

The configuration for the email sent when an app user forgets their
password.

=head1 ATTRIBUTES


=head2 EmailMessage => Str

The body of the email.


=head2 EmailSubject => Str

The subject of the email.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::AmplifyBackend>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

