# Generated by default/object.tt
package Paws::Route53Resolver::FirewallRuleGroup;
  use Moose;
  has Arn => (is => 'ro', isa => 'Str');
  has CreationTime => (is => 'ro', isa => 'Str');
  has CreatorRequestId => (is => 'ro', isa => 'Str');
  has Id => (is => 'ro', isa => 'Str');
  has ModificationTime => (is => 'ro', isa => 'Str');
  has Name => (is => 'ro', isa => 'Str');
  has OwnerId => (is => 'ro', isa => 'Str');
  has RuleCount => (is => 'ro', isa => 'Int');
  has ShareStatus => (is => 'ro', isa => 'Str');
  has Status => (is => 'ro', isa => 'Str');
  has StatusMessage => (is => 'ro', isa => 'Str');

1;

### main pod documentation begin ###

=head1 NAME

Paws::Route53Resolver::FirewallRuleGroup

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Route53Resolver::FirewallRuleGroup object:

  $service_obj->Method(Att1 => { Arn => $value, ..., StatusMessage => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Route53Resolver::FirewallRuleGroup object:

  $result = $service_obj->Method(...);
  $result->Att1->Arn

=head1 DESCRIPTION

High-level information for a firewall rule group. A firewall rule group
is a collection of rules that DNS Firewall uses to filter DNS network
traffic for a VPC. To retrieve the rules for the rule group, call
ListFirewallRules.

=head1 ATTRIBUTES


=head2 Arn => Str

The ARN (Amazon Resource Name) of the rule group.


=head2 CreationTime => Str

The date and time that the rule group was created, in Unix time format
and Coordinated Universal Time (UTC).


=head2 CreatorRequestId => Str

A unique string defined by you to identify the request. This allows you
to retry failed requests without the risk of running the operation
twice. This can be any unique string, for example, a timestamp.


=head2 Id => Str

The ID of the rule group.


=head2 ModificationTime => Str

The date and time that the rule group was last modified, in Unix time
format and Coordinated Universal Time (UTC).


=head2 Name => Str

The name of the rule group.


=head2 OwnerId => Str

The AWS account ID for the account that created the rule group. When a
rule group is shared with your account, this is the account that has
shared the rule group with you.


=head2 RuleCount => Int

The number of rules in the rule group.


=head2 ShareStatus => Str

Whether the rule group is shared with other AWS accounts, or was shared
with the current account by another AWS account. Sharing is configured
through AWS Resource Access Manager (AWS RAM).


=head2 Status => Str

The status of the domain list.


=head2 StatusMessage => Str

Additional information about the status of the rule group, if
available.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Route53Resolver>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

