# Generated by default/object.tt
package Paws::DevOpsGuru::ReactiveInsight;
  use Moose;
  has Id => (is => 'ro', isa => 'Str');
  has InsightTimeRange => (is => 'ro', isa => 'Paws::DevOpsGuru::InsightTimeRange');
  has Name => (is => 'ro', isa => 'Str');
  has ResourceCollection => (is => 'ro', isa => 'Paws::DevOpsGuru::ResourceCollection');
  has Severity => (is => 'ro', isa => 'Str');
  has SsmOpsItemId => (is => 'ro', isa => 'Str');
  has Status => (is => 'ro', isa => 'Str');

1;

### main pod documentation begin ###

=head1 NAME

Paws::DevOpsGuru::ReactiveInsight

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::DevOpsGuru::ReactiveInsight object:

  $service_obj->Method(Att1 => { Id => $value, ..., Status => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::DevOpsGuru::ReactiveInsight object:

  $result = $service_obj->Method(...);
  $result->Att1->Id

=head1 DESCRIPTION

Information about a reactive insight. This object is returned by
C<ListInsights>.

=head1 ATTRIBUTES


=head2 Id => Str

The ID of a reactive insight.


=head2 InsightTimeRange => L<Paws::DevOpsGuru::InsightTimeRange>




=head2 Name => Str

The name of a reactive insight.


=head2 ResourceCollection => L<Paws::DevOpsGuru::ResourceCollection>




=head2 Severity => Str

The severity of a reactive insight.


=head2 SsmOpsItemId => Str

The ID of the AWS System Manager OpsItem created for this insight. You
must enable the creation of OpstItems insights before they are created
for each insight.


=head2 Status => Str

The status of a reactive insight.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::DevOpsGuru>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

