# Generated by default/object.tt
package Paws::Chime::VoiceConnectorGroup;
  use Moose;
  has CreatedTimestamp => (is => 'ro', isa => 'Str');
  has Name => (is => 'ro', isa => 'Str');
  has UpdatedTimestamp => (is => 'ro', isa => 'Str');
  has VoiceConnectorGroupId => (is => 'ro', isa => 'Str');
  has VoiceConnectorItems => (is => 'ro', isa => 'ArrayRef[Paws::Chime::VoiceConnectorItem]');

1;

### main pod documentation begin ###

=head1 NAME

Paws::Chime::VoiceConnectorGroup

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Chime::VoiceConnectorGroup object:

  $service_obj->Method(Att1 => { CreatedTimestamp => $value, ..., VoiceConnectorItems => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Chime::VoiceConnectorGroup object:

  $result = $service_obj->Method(...);
  $result->Att1->CreatedTimestamp

=head1 DESCRIPTION

The Amazon Chime Voice Connector group configuration, including
associated Amazon Chime Voice Connectors. You can include Amazon Chime
Voice Connectors from different AWS Regions in your group. This creates
a fault tolerant mechanism for fallback in case of availability events.

=head1 ATTRIBUTES


=head2 CreatedTimestamp => Str

The Amazon Chime Voice Connector group creation time stamp, in ISO 8601
format.


=head2 Name => Str

The name of the Amazon Chime Voice Connector group.


=head2 UpdatedTimestamp => Str

The updated Amazon Chime Voice Connector group time stamp, in ISO 8601
format.


=head2 VoiceConnectorGroupId => Str

The Amazon Chime Voice Connector group ID.


=head2 VoiceConnectorItems => ArrayRef[L<Paws::Chime::VoiceConnectorItem>]

The Amazon Chime Voice Connectors to which to route inbound calls.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Chime>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

