
package Paws::EFS::ListTagsForResource;
  use Moose;
  has MaxResults => (is => 'ro', isa => 'Int', traits => ['ParamInQuery'], query_name => 'MaxResults');
  has NextToken => (is => 'ro', isa => 'Str', traits => ['ParamInQuery'], query_name => 'NextToken');
  has ResourceId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'ResourceId', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'ListTagsForResource');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/2015-02-01/resource-tags/{ResourceId}');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EFS::ListTagsForResourceResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EFS::ListTagsForResource - Arguments for method ListTagsForResource on L<Paws::EFS>

=head1 DESCRIPTION

This class represents the parameters used for calling the method ListTagsForResource on the
L<Amazon Elastic File System|Paws::EFS> service. Use the attributes of this class
as arguments to method ListTagsForResource.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to ListTagsForResource.

=head1 SYNOPSIS

    my $elasticfilesystem = Paws->service('EFS');
    my $ListTagsForResourceResponse = $elasticfilesystem->ListTagsForResource(
      ResourceId => 'MyResourceId',
      MaxResults => 1,                # OPTIONAL
      NextToken  => 'MyToken',        # OPTIONAL
    );

    # Results:
    my $NextToken = $ListTagsForResourceResponse->NextToken;
    my $Tags      = $ListTagsForResourceResponse->Tags;

    # Returns a L<Paws::EFS::ListTagsForResourceResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/elasticfilesystem/ListTagsForResource>

=head1 ATTRIBUTES


=head2 MaxResults => Int

(Optional) Specifies the maximum number of tag objects to return in the
response. The default value is 100.



=head2 NextToken => Str

(Optional) You can use C<NextToken> in a subsequent request to fetch
the next page of access point descriptions if the response payload was
paginated.



=head2 B<REQUIRED> ResourceId => Str

Specifies the EFS resource you want to retrieve tags for. You can
retrieve tags for EFS file systems and access points using this API
endpoint.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method ListTagsForResource in L<Paws::EFS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

